from typing import NewType

Microseconds = NewType("Microseconds", float)
Milliseconds = NewType("Milliseconds", float)
Seconds = NewType("Seconds", float)
Minutes = NewType("Minutes", float)
Hours = NewType("Hours", float)
Days = NewType("Days", float)



from datetime import datetime
from enum import Enum, unique


@unique
class Weekday(Enum):
    MONDAY = 0
    TUESDAY = 1
    WEDNESDAY = 2
    THURSDAY = 3
    FRIDAY = 4
    SATURDAY = 5
    SUNDAY = 6

    @classmethod
    def from_datetime(cls, dt: datetime) -> "Weekday":
        return cls(dt.weekday())



from datetime import time, timedelta

from .constants import S_IN_H, S_IN_MIN, US_IN_S
from .units import Microseconds


def time_in_microseconds(time: time) -> Microseconds:
    return Microseconds(
        (time.hour * S_IN_H + time.minute * S_IN_MIN + time.second) * US_IN_S
        + time.microsecond
    )


def subtract_times(first: time, second: time) -> timedelta:
    # Subtract two times
    assert first.tzinfo == second.tzinfo, "Timezones must match"
    return timedelta(
        microseconds=time_in_microseconds(first) - time_in_microseconds(second)
    )
